﻿(function ($, window) {
    window.FXStreetPush = {};
    var FXStreetPush = window.FXStreetPush;

    FXStreetPush.Utils = (function () {
        var getUrlParameter = function (name) {
            name = name.replace(/[\[]/, '\\[').replace(/[\]]/, '\\]');
            var regex = new RegExp('[\\?&]' + name + '=([^&#]*)');
            var results = regex.exec(location.search);
            return results === null ? '' : decodeURIComponent(results[1].replace(/\+/g, ' '));
        };

        var isJQueryGreaterThan_1_8 = function () {
            var vernums = $.fn.jquery.split('.');
            var result = parseInt(vernums[0]) > 0 && parseInt(vernums[1]) >= 8;
            return result;
        };

        var invokeThen = function (promise, ok, err, notify) {
            if (isJQueryGreaterThan_1_8()) {
                return promise.then(ok, err, notify);
            }
            else {
                return promise.pipe(ok, err, notify);
            }
        };

        var isObject = function (obj) {
            return obj !== null && typeof obj === 'object'
        };

        var newGuid = function () {
            function S4() {
                return (((1 + Math.random()) * 0x10000) | 0).toString(16).substring(1);
            }
            var result = (S4() + S4() + "-" + S4() + "-4" + S4().substr(0, 3) + "-" + S4() + "-" + S4() + S4() + S4()).toLowerCase();
            return result;
        };

        return {
            getUrlParameter: getUrlParameter,
            invokeThen: invokeThen,
            isObject: isObject,
            newGuid: newGuid
        };
    })();

    FXStreetPush.PushNotification = (function () {
        var instance;

        var pushNotificationClass = function () {
            var config = {
                token: null,
                tokenUrl: "https://authorization.fxstreet.com/token",
                httpPushServerUrl: "https://httppush.fxstreet.com/signalr/hubs",
                logging: false,
                postHub: 'postHub',
                tradingPositionHub: 'ctpHub',
                marketImpactHub: 'marketImpactHub',
                calendarHub: 'calendarHub',
                editorialToolsHub: 'editorialToolsHub',
                postServerFunc: 'postCreated',
                globalAlertServerFunc: 'globalAlertCreated',
                tradingPositionServerFunc: 'ctpCreated',
                calendarServerFunc: 'updatedValues',
                marketImpactServerFunc: 'updatedValues',
                culture: "en-US",
                restartMilliseconds: 2000,
                pingIntervalMilliseconds: 6000,
                pingIntervalRetries: 10,
                disconnectedHandler: function () { }
            };
            var tryingToReconnect = false;
            var getConnectionPromise = null;
            var startConnectionPromise = null;
            var restartPromise = null;
            var stopAndRestart = false;
            var connectionSignalR = null;
            var self = this;
            var pingIntervalId = null;
            var tradingPositionSubscribeObj = null;
            var calendarSubscribeObj = null;
            var marketImpactSubscribeObj = null;
            var globalAlertSubscribeObj = null;            
            var postSubscriberObj = null;
            var retriesCount = 0;

            self.id = FXStreetPush.Utils.newGuid();

            this.init = function (options) {
                if ($.type(options) === "object") {
                    $.extend(true, config, options);
                }
                config.logging = config.logging
                    || FXStreetPush.Utils.getUrlParameter('fxslogging') !== '';

                connectionSignalR = null;
                stopAndRestart = false;
                getConnectionPromise = null;
                startConnectionPromise = null;
                restartPromise = null;
                tryingToReconnect = false;

                tradingPositionSubscribeObj = new subscriberBase(config.tradingPositionHub, config.tradingPositionServerFunc);
                calendarSubscribeObj = new subscriberBase(config.calendarHub, config.calendarServerFunc);
                marketImpactSubscribeObj = new subscriberBase(config.marketImpactHub, config.marketImpactServerFunc);
                globalAlertSubscribeObj = new subscriberBase(config.editorialToolsHub, config.globalAlertServerFunc);
                postSubscriberObj = new postSubscriber(config.postHub, config.postServerFunc, config.culture, logger);

                configurePingInterval();
            };

            var configurePingInterval = function () {
                if (!pingIntervalId && !isNaN(config.pingIntervalMilliseconds)) {
                    pingIntervalId = window.setInterval(function () {
                        if (self.getState() === 'disconnected' && !stopAndRestart) {
                              if (retriesCount === config.pingIntervalRetries) {
                                  clearInterval(pingIntervalId);
                                if (config.logging) {
                                    config.disconnectedHandler();
                                }
                            }
                            else {
                                  retriesCount++;
                                  restart().fail(function (error) {
                                    logger("FXSPush: pingIntervalId restart fail: " + error);
                                    reinit();
                                });
                            }
                        }
                        else if (self.getState() === 'connected') {
                            retriesCount = 0;
                        }
                    }, config.pingIntervalMilliseconds);
                }
            };

            this.getState = function (connection) {
                var connectionState = ['connecting', 'connected', 'reconnecting', '', 'disconnected'];
                var result = connectionState[4];
                var conn = connection || connectionSignalR;
                if (conn) {
                    result = connectionState[conn.state];
                }
                return result;
            };

            var logger = function (message) {
                if (config.logging) {
                    console.log(message);
                    if (window.FXStreet && FXStreet.Log) {
                        var eventData = {
                            Id: self.id,
                            State: self.getState(),
                            DateTimeUtc: new Date().toISOString(),
                            UserAgent: navigator.userAgent,
                            Message: JSON.stringify(message),
                        };
                        FXStreet.Log.LogMessage(eventData);
                    }
                }
            };

            var getToken = function () {
                if (FXStreetPush.Utils.isObject(config.token)) {
                    return $.when(config.token);
                }
                return $.ajax({
                    type: "POST",
                    url: config.tokenUrl,
                    contentType: "application/x-www-form-urlencoded",
                    dataType: "json",
                    data: {
                        grant_type: "domain",
                        client_id: "client_id"
                    }
                })
                    .fail(function (error) {
                        logger(error);
                    });
            };

            var getConnection = function () {
                if (connectionSignalR) {
                    return FXStreetPush.Utils.invokeThen($.when(), (function () {
                        return connectionSignalR;
                    }));
                }
                else {
                    if (!getConnectionPromise) {
                        getConnectionPromise = FXStreetPush.Utils.invokeThen(getToken(), function (token) {
                            connectionSignalR = $.hubConnection();
                            connectionSignalR.url = config.httpPushServerUrl;
                            connectionSignalR.logging = config.logging;
                            connectionSignalR.qs = "access_token=" + token.access_token;
                            connectionSignalR.error(function (error) {
                                logger('FXSPush ' + error);
                            });
                            connectionSignalR.connectionSlow(function () {
                                logger('FXSPush ConnectionSlow: We are currently experiencing difficulties with the connection.');
                            });
                            connectionSignalR.stateChanged(stateChange);
                            connectionSignalR.reconnecting(reconnecting);
                            connectionSignalR.reconnected(reconnected);
                            connectionSignalR.disconnected(disconnected);

                            getConnectionPromise = null;
                            return connectionSignalR;
                        }, function (error) {
                            getConnectionPromise = null;
                            logger('FXSPush getConnection : ' + error);
                        });
                    }
                    return getConnectionPromise;
                }
            };

            var stateChange = function (change) {
                logger(change);
                if (change.newState === 1) {
                    startConnectionDone(connectionSignalR);
                    if (isNecessaryRestart(connectionSignalR)) {
                        return stopAndStartConnection(connectionSignalR);
                    }
                    else {
                        tradingPositionSubscribeObj.reconnected();
                        calendarSubscribeObj.reconnected();
                        postSubscriberObj.reconnected();
                        marketImpactSubscribeObj.reconnected();
                        globalAlertSubscribeObj.reconnected();
                    }
                }
            };

            var reconnected = function () {
                logger('FXSPush reconnected');
                tryingToReconnect = false;
            };

            var disconnected = function () {
                logger('FXSPush disconnected');
                if (!stopAndRestart) {
                    var milliseconds = tryingToReconnect ? 0 : config.restartMilliseconds;
                    setTimeout(function () {
                        restart().fail(function (error) {
                            logger("FXSPush: disconnected restart fail: " + error);
                        });
                    }, milliseconds);
                }
            };

            var reconnecting = function () {
                logger('FXSPush reconnecting');
                tryingToReconnect = true;
            };

            var startConnectionDone = function (connection) {
                startConnectionPromise = null;
                var msg = "FXSPush StartConnectionDone, transport = ";
                if (connection && connection.transport)
                    msg = msg + connection.transport.name;
                logger(msg);
            };

            var startConnectionFail = function (error) {
                startConnectionPromise = null;
                logger('FXSPush: Connection Start error: ' + error);
            };

            var isNecessaryRestartByHub = function (connection, hubName) {
                var result = false;
                if (hubName && connection.data) {
                    var connectedHubs = JSON.parse(connection.data);
                    var connecteHub = $.grep(connectedHubs, function (item) {
                        return item.name.toLowerCase() === hubName.toLowerCase();
                    });
                    result = connecteHub.length === 0;
                }
                return result;
            };

            var isNecessaryRestart = function (connection) {
                var result = self.getState(connection) === 'connected'
                    && (
                        (postSubscriberObj.getProxy() && isNecessaryRestartByHub(connection, config.postHub)) ||
                        (tradingPositionSubscribeObj.getProxy() && isNecessaryRestartByHub(connection, config.tradingPositionHub)) ||
                        (calendarSubscribeObj.getProxy() && isNecessaryRestartByHub(connection, config.calendarHub)) ||
                        (marketImpactSubscribeObj.getProxy() && isNecessaryRestartByHub(connection, config.marketImpactHub)) ||
                        (globalAlertSubscribeObj.getProxy() && isNecessaryRestartByHub(connection, config.editorialToolsHub))

                    );
                return result;
            };

            var stopAndStartConnection = function (connection) {
                stopAndRestart = true;
                return FXStreetPush.Utils.invokeThen($.when(connection.stop()),
                    function () {
                        return startConnection(connection)
                            .done(function () {
                                stopAndRestart = false;
                            })
                            .fail(function (error) {
                                stopAndRestart = false;
                            })
                    });
            };

            var isNecessaryStart = function (connection) {
                var state = self.getState(connection);
                return state === '' || state === 'disconnected';
            };
            var startConnection = function (connection) {
                if (startConnectionPromise)
                    return startConnectionPromise;
                else if (isNecessaryStart(connection)) {
                    startConnectionPromise = connection.start()
                        .fail(function (error) {
                            startConnectionFail(error)
                        });
                    return startConnectionPromise;
                }
                else if (isNecessaryRestart(connection)) {
                    startConnectionPromise = stopAndStartConnection(connection);
                    return startConnectionPromise;
                }
                else {
                    return $.when();
                }
            };

            var restart = function () {
                if (!restartPromise) {
                    restartPromise = FXStreetPush.Utils.invokeThen(getConnection(),
                        function (connection) {
                            restartPromise = null;
                            return startConnection(connection);
                        });
                }
                return restartPromise;
            };

            var reinit = function () {
                var postSubscriberObjTemp = postSubscriberObj;
                var tradingPositionSubscribeObjTemp = tradingPositionSubscribeObj;
                var calendarSubscribeObjTemp = calendarSubscribeObj;
                var marketImpactSubscribeObjTemp = marketImpactSubscribeObj;
                var globalAlertSubscribeObjTemp = globalAlertSubscribeObj;

                self.init(config);
                stopAndRestart = true;
                try {
                    if (postSubscriberObjTemp.anyCallback())
                        self.postSubscribe(postSubscriberObjTemp.getChannels(), postSubscriberObjTemp.getCallbacks());

                    if (tradingPositionSubscribeObjTemp.anyCallback())
                        self.tradingPositionSubscribe(tradingPositionSubscribeObjTemp.getCallbacks());

                    if (calendarSubscribeObjTemp.anyCallback())
                        self.calendarSubscribe(calendarSubscribeObjTemp.getCallbacks());

                    if (marketImpactSubscribeObjTemp.anyCallback())
                        self.marketImpactSubscribe(marketImpactSubscribeObj.getCallbacks());

                    if (globalAlertSubscribeObjTemp.anyCallback())
                        self.globalAlertSubscribe(globalAlertSubscribeObj.getCallbacks());
                }
                catch (error) {
                    throw error;
                }
                finally {
                    stopAndRestart = false;
                }
            }

            this.postSubscribe = function (channels, callback) {
                postSubscriberObj.setCallback(callback);
                postSubscriberObj.setChannels(channels);
                FXStreetPush.Utils.invokeThen(getConnection(), function (connection) {
                    postSubscriberObj.setProxy(connection);
                    startConnection(connection);
                });
            };

            this.tradingPositionSubscribe = function (callback) {
                tradingPositionSubscribeObj.setCallback(callback);
                FXStreetPush.Utils.invokeThen(getConnection(), function (connection) {
                    tradingPositionSubscribeObj.setProxy(connection);
                    startConnection(connection);
                });
            };

            this.calendarSubscribe = function (callback) {
                calendarSubscribeObj.setCallback(callback);
                FXStreetPush.Utils.invokeThen(getConnection(), function (connection) {
                    calendarSubscribeObj.setProxy(connection);
                    startConnection(connection);
                });
            };

            this.marketImpactSubscribe = function (callback) {
                marketImpactSubscribeObj.setCallback(callback);
                FXStreetPush.Utils.invokeThen(getConnection(), function (connection) {
                    marketImpactSubscribeObj.setProxy(connection);
                    startConnection(connection);
                });
            };

            this.globalAlertSubscribe = function (callback) {
                globalAlertSubscribeObj.setCallback(callback);
                FXStreetPush.Utils.invokeThen(getConnection(), function (connection) {
                    globalAlertSubscribeObj.setProxy(connection);
                    startConnection(connection);
                });
            };

        };

        var subscriberBase = function (hubName, serverFunc) {
            var callbackDelegates = [];
            var proxy = null;

            this.Notify = function (item) {
                for (var i = 0; i < callbackDelegates.length; i++) {
                    callbackDelegates[i]($.extend(true, {}, item));
                }
            }

            this.setProxy = function (connection) {
                if (!proxy) {
                    proxy = connection.createHubProxy(hubName);
                    proxy.on(serverFunc, this.Notify);
                }
            };

            this.getProxy = function () {
                return proxy;
            };

            this.setCallback = function (callback) {
                if (Array.isArray(callback)) {
                    for (var i = 0; i < callback.length; i++) {
                        if (typeof callback === 'function') {
                            callbackDelegates.push(callback[i]);
                        }
                    }
                }
                else if (typeof callback === 'function') {
                    callbackDelegates.push(callback);
                }
            }

            this.getCallbacks = function () {
                return callbackDelegates;
            };

            this.anyCallback = function () {
                return callbackDelegates.length > 0;
            };

            this.reconnected = function () { };
        };

        var postSubscriber = function (hubName, serverFunc, culture, loggerDelegate) {
            subscriberBase.call(this, hubName, serverFunc);
            var hubChannels = [];
            this.setChannels = function (channels) {
                if (!Array.isArray(channels) || channels.length === 0) {
                    throw new Error("channels.length === 0");
                }
                hubChannels = channels;
            }
            this.getChannels = function (channels) {
                return hubChannels;
            };

            this.reconnected = function () {
                var postProxy = this.getProxy();
                if (postProxy && this.anyCallback()) {
                    for (var i = 0; i < hubChannels.length; i++) {
                        postInvoke(postProxy, hubChannels[i]);
                    }
                }
            };

            var postInvoke = function (proxy, channel) {
                proxy.invoke("subscribe", culture, channel)
                    .done(function () {
                        loggerDelegate('FXSPush: Subscribe done: ' + channel);
                    })
                    .fail(function (error) {
                        loggerDelegate('FXSPush: Subscribe error: ' + error);
                    });
            };
        };

        return {
            getInstance: function (options) {
                if (!instance) {
                    instance = new pushNotificationClass();
                    instance.init(options);
                }
                return instance;
            }
        };
    })();

}(window.jQuery, window));